@@ -53,9 +53,15 @@ class ClarityConverter(object):
 
         return office_id
 
-    @classmethod
-    def get_choice_id(cls, name):
-        return slugify(name, separator="_")
+    def get_choice_id(self, name, party=None, race_id=None):
+        if party and party == "REP":
+            party = "GOP"
+        if party and party == "NP":
+            party = None
+        choice_id = "_".join(filter(None, [race_id, party, slugify(name, separator="_")]))
+        if self.candidate_lookup:
+            choice_id = self.candidate_lookup.get(choice_id, choice_id)
+        return choice_id
 
     def get_precinct_id(self, name, county_id=None):
         return "_".join(filter(None,[county_id, slugify(name, separator='-')]))
